// src/python_cpu_policy_manager.hh - Copyright 2005, 2006, University
//               of Padova, dept. of Pure and Applied
//               Mathematics
//
// This file is part of SGPEMv2.
//
// This is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// SGPEMv2 is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with SGPEMv2; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

#ifndef PYTHON_CPU_POLICY_MANAGER_HH
#define PYTHON_CPU_POLICY_MANAGER_HH 1

#include "config.h"

#include <Python.h>

#include "cpu_policy_manager.hh"
#include "python_cpu_policy.hh"

namespace sgpem
{
  //class CPUPolicyManager;
  class PythonCPUPolicyManager;

  /** \brief Manages Python user-implemented policies
   * 
   * This singleton manages the creation and destruction 
   * of a Python policy.
   */
  class SG_DLLEXPORT PythonCPUPolicyManager : public CPUPolicyManager
  {
  public:
    PythonCPUPolicyManager();
    ~PythonCPUPolicyManager();

    /** \brief Initialize the Python interpreter.
     *
     * If the interpreter has already been initialized, it terminates it, cleanups old policies,
     * and restarts it.
     */
    void init();

    const std::vector<CPUPolicy*>&  get_avail_policies();

  protected:
    /** The selected and active PyhonCPUPolicy object. */
    void collect_policies();

  private:
    PythonCPUPolicyManager(const PythonCPUPolicyManager&);
    PythonCPUPolicyManager& operator=(const PythonCPUPolicyManager&);

    bool _initialized;
  };

}

#endif

